# Laskea

Calculate (Finnish: laskea) some parts.

[License: MIT](https://git.sr.ht/~sthagen/laskea/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [docs/third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![downloads](https://pepy.tech/badge/laskea/month)](https://pepy.tech/project/laskea)
[![wheel](https://img.shields.io/pypi/wheel/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![supported-versions](https://img.shields.io/pypi/pyversions/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)
[![supported-implementations](https://img.shields.io/pypi/implementation/laskea.svg?style=flat)](https://pypi.python.org/pypi/laskea/)

## Documentation

User and developer [documentation of laskea](https://codes.dilettant.life/docs/laskea).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of laskea](https://todo.sr.ht/~sthagen/laskea).

## Primary Source repository

The primary source of `laskea` lives somewhere on a mountain in Central Switzerland.
But, we use decentralized version control (git), so any clone can become the source to everyone's benefit, no central only code.
Anyway, the preferred public clones of `laskea` are:

* [on codeberg](https://codeberg.org/sthagen/laskea) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/laskea) - a collection of tools useful for software development.

## Status

Production/Stable.

**Note**: The default branch is `default`.
